.. _part_bod:

======================================================
Bodies, Inertias, Loads & Other Functions (Docstrings)
======================================================

Bodies
======

.. autoclass:: sympy.physics.mechanics.particle.Particle
   :members:
   :inherited-members:

.. autoclass:: sympy.physics.mechanics.rigidbody.RigidBody
   :members:
   :inherited-members:

Inertias
========

.. autoclass:: sympy.physics.mechanics.inertia.Inertia
   :members:

.. autofunction:: sympy.physics.mechanics.inertia.inertia

.. autofunction:: sympy.physics.mechanics.inertia.inertia_of_point_mass

Loads
=====

.. autoclass:: sympy.physics.mechanics.loads.Force
   :members:

.. autoclass:: sympy.physics.mechanics.loads.Torque
   :members:

Other Functions
===============

.. autofunction:: sympy.physics.mechanics.functions.center_of_mass

.. autofunction:: sympy.physics.mechanics.functions.linear_momentum

.. autofunction:: sympy.physics.mechanics.functions.angular_momentum

.. autofunction:: sympy.physics.mechanics.functions.kinetic_energy

.. autofunction:: sympy.physics.mechanics.functions.potential_energy

.. autofunction:: sympy.physics.mechanics.functions.Lagrangian

.. autofunction:: sympy.physics.mechanics.functions.find_dynamicsymbols
